@@ -1,7 +1,6 @@
 #ifndef DAYPERIOD_H
 #define DAYPERIOD_H
 #include <QListWidgetItem>
-#include "commonIncludes.h"
 
 class DayPeriod : public QObject
 {
@@ -10,8 +9,8 @@ class DayPeriod : public QObject
 public:
     DayPeriod(int day);
     ~DayPeriod();
-    void setInfo(QString &title, QString &condition, QString &temperature, QString &iconURL);
-
+    void setInfo(QString &title, QString &condition, QString &temperature);
+    void setIcon(QIcon* icon);
     QListWidgetItem* getItem(){
         return listItem;
     }
@@ -19,11 +18,11 @@ public:
     int dayNum;
     void setLoading();
 
-public slots:
-    void requestFinished(QNetworkReply *reply);
+//public slots:
+//    void requestFinished(QNetworkReply *reply);
 
 private:
-    QNetworkAccessManager* manager;
+//    QNetworkAccessManager* manager;
     QListWidgetItem* listItem;
 };
 
