@@ -2,7 +2,11 @@
 #define STACKEDWINDOW_H
 
 #include <QMainWindow>
-#include "commonIncludes.h"
+#include <QResizeEvent>
+#include <QNetworkAccessManager>
+#include <QUrl>
+#include <QNetworkReply>
+#include <QSignalMapper>
 
 namespace Ui {
     class StackedWindow;
@@ -13,25 +17,23 @@ class StackedWindow : public QMainWindow
     Q_OBJECT
 
 public:
-    explicit StackedWindow(QString latlong, QString wso, QString zcode, QString offset, QString &dayIcon, QString &nightIcon, QWidget *parent = 0);
+    explicit StackedWindow(QString* latlong, QString* wso, QString* zcode,
+                           QString* offset, QPixmap* dayIcon, QString* dayURL,
+                           QPixmap* nightIcon, QString* nightURL, QWidget *parent = 0);
     ~StackedWindow();
     void setInfo(QString &day, QString &hi, QString &lo, QString &precip, QString &dayFor, QString &nightFor);
 
+
 protected:
     virtual void resizeEvent(QResizeEvent * event);
 
-public slots:
-    void loadLabel(QNetworkReply *reply);
-    void loadPrecip(QNetworkReply *reply);
-    void loadDayIcon(QNetworkReply *reply);
-    void loadNightIcon(QNetworkReply *reply);
+private slots:
+    void setIcons(int mapping);
 
 private:
     Ui::StackedWindow *ui;
+    QSignalMapper* mapper;
     QNetworkAccessManager *manager;
-    QNetworkAccessManager *manager2;
-    QNetworkAccessManager *manager3;
-    QNetworkAccessManager *manager4;
 };
 
 #endif // STACKEDWINDOW_H
